@@ -17,7 +17,7 @@
  ******************************** LICENSE ********************************/
 
 /*! \file GribDecoder.cc
-    \brief Implementation of the Template class GribDecoder.
+    \brief Implementation of the class GribDecoder.
 
     Magics Team - ECMWF 2004
 
@@ -72,9 +72,7 @@ GribDecoder::~GribDecoder()
     if ( xComponent_ ) delete xComponent_;
     if ( yComponent_ ) delete yComponent_;
     if ( handle_ ) {
-
         grib_handle_delete (handle_);
-
     }
 
     if (nearest_)
@@ -101,8 +99,8 @@ void GribDecoder::set(const GribLoop& loop, int index)
     missing_fill_count_ = loop.missing_fill_count_;
     wind_mode_       = auto_ptr<WindMode>(loop.wind_mode_->clone());
     internalIndex_ = index;
-
 }
+
 long computeStep( const GribDecoder& grib,const string&  key)
 {
     static map<string, double> stepUnits;
@@ -129,6 +127,7 @@ long computeStep( const GribDecoder& grib,const string&  key)
         factor = stepunit->second;
     return step * factor;
 }
+
 long GribDecoder::getLong(const string& key, bool warnIfKeyAbsent) const
 {
     long val;
@@ -151,7 +150,6 @@ long GribDecoder::getLong(const string& key, bool warnIfKeyAbsent) const
 
 string GribDecoder::getstring(const string& key, bool warnIfKeyAbsent, bool cache) const
 {
-
     if ( cache ) {
         map<string, string>::const_iterator sk = sKeys_.find(key);
         if ( sk != sKeys_.end() ) {
@@ -178,7 +176,6 @@ string GribDecoder::getstring(const string& key, bool warnIfKeyAbsent, bool cach
 
 string GribDecoder::getString(const string& key, bool warnIfKeyAbsent) const
 {
-
     if ( Data::dimension_ == 1 )
         return getstring(key, warnIfKeyAbsent, false);
 
@@ -228,7 +225,6 @@ double GribDecoder::getDouble(const string& key, bool warnIfKeyAbsent) const
 
 void   GribDecoder::setDouble(const string& key, double val) const
 {
-
     int err = grib_set_double(handle_, key.c_str(), val);
     if ( err )
     {
@@ -246,13 +242,11 @@ void GribDecoder::scale(const string& metadata, double& scaling, double& offset)
 	}
 	ParamJSon data = ParamJSon(metadata);
 
-
 	long table = 128; // hard-coded in case of GRIB 2
 	long centre = 98;  // hard-coded in case of GRIB 2
 
 	ParamJSon::iterator pid = data.find("paramId");
 
-
 	long id = ( pid != data.end() )  ? tonumber(pid->second) : 0;
 
 	try {
@@ -263,12 +257,8 @@ void GribDecoder::scale(const string& metadata, double& scaling, double& offset)
 
 	}
 	catch (...) {
-		MagLog::warning()
-		<< " Can not find information for the parameter [" << id
-														 << "." << table << "]\n";
+		MagLog::warning() << " Can not find information for the parameter [" << id << "." << table << "]\n";
 	}
-
-
 }
 
 void GribDecoder::read(Matrix **matrix)
@@ -294,13 +284,12 @@ void GribDecoder::read(Matrix **matrix)
             MagLog::error() <<  msg.str() << std::endl;
             throw MagicsException(msg.str());
         }
-
         interpretor_->scaling(*this, matrix);
     }
     catch (NoFactoryException&)
     {
         ostringstream msg;
-        msg << "Grib Decoder: Representation [" << representation << "] not yet supported";
+        msg << "Grib Decoder - read: Representation [" << representation << "] not supported";
         MagLog::error() << msg.str() << endl;
         valid_ = false;
         throw MagicsException(msg.str());
@@ -327,9 +316,9 @@ void GribDecoder::read(Matrix **matrix, const Transformation&  transformation)
     }
     catch (NoFactoryException&)
     {
-        MagLog::error() << "Grib Decoder: Representation [" << representation << "] not yet supported.\n"<< std::endl;;
+        MagLog::error() << "Grib Decoder - read: Representation [" << representation << "] not supported.\n"<< std::endl;;
         valid_ = false;
-        throw MagicsException("Grib Decoder: Representation [] not yet supported.");
+        throw MagicsException("Grib Decoder: Representation [] not supported.");
     }
 }
 
@@ -368,30 +357,24 @@ void GribDecoder::release()
         *point = 0;
     }
     points_.clear();
-
 }
+
 void GribDecoder::visit(Transformation& transformation)
 {
-
     if(transformation.coordinateType() == Transformation::GeoType )
         return;
     decode();
     // Here are in a dump ode .. the coordinates are pixels.
     if ( transformation.getAutomaticX() ) {
         transformation.setMinMaxX(1, matrix_->columns());
-
     }
     if ( transformation.getAutomaticY() ) {
         transformation.setMinMaxY(1, matrix_->rows());
-
     }
-
-
-
 }
+
 void GribDecoder::decode2D()
 {
-
     if (xComponent_) return;
     Matrix     *w1 = 0;
     Matrix     *w2 = 0;
@@ -407,9 +390,8 @@ void GribDecoder::decode2D()
     }
     catch (NoFactoryException&)
     {
-        MagLog::warning() << "Grib Decoder: Representation [" << representation << "] not yet supported.\n"<< std::endl;;
+        MagLog::warning() << "Grib Decoder: Vector cobination of representations [" << representation << "] not supported.\n"<< std::endl;;
         valid_ = false;
-
     }
     readColourComponent();
     openFirstComponent();
@@ -418,8 +400,6 @@ void GribDecoder::decode2D()
     read(&w2);
     Data::dimension_ = ( colourComponent_ ) ? 3 : 2;
 
-
-
     wind_mode_->x(&xComponent_, &yComponent_, w1, w2);
     interpretor_->keepOriginal(false);
 }
@@ -427,7 +407,6 @@ void GribDecoder::decode2D()
 
 void GribDecoder::customisedPoints(const AutomaticThinningMethod& thinning, const Transformation& transformation, const std::set<string>& request, CustomisedPointsList& points)
 {
-
     openFirstComponent();
     long repres;
     grib_get_long(handle_,"dataRepresentationType",&repres);
@@ -439,7 +418,6 @@ void GribDecoder::customisedPoints(const AutomaticThinningMethod& thinning, cons
 
         // Compute the thinning factor...
 
-
         double x1 = 0;
         double y1 = 60;
         double x2 = 0;
@@ -454,22 +432,15 @@ void GribDecoder::customisedPoints(const AutomaticThinningMethod& thinning, cons
         double ystep = ( transformation.getMaxPCY() - transformation.getMinPCY())/ (thinning.y()-1);
 
         int nb = (xstep/res);
-
-
-
         xstep = nb * res;
         ystep = int(ystep/res) * res;
 
-
         customisedPoints(transformation, points, xstep, ystep, 0);
-
-
-
     }
     catch (NoFactoryException&)
     {
-        MagLog::error() << "Grib Decoder: Representation [" << representation << "] not yet supported.\n"<< std::endl;;
-        throw MagicsException("Grib Decoder: Representation [] not yet supported.");
+        MagLog::error() << "Grib Decoder - customisedPoints: Representation [" << representation << "] not supported.\n"<< std::endl;;
+        throw MagicsException("Grib Decoder: Representation [] not supported.");
     }
 }
 
@@ -499,7 +470,6 @@ bool compare(const pair<double, double>& pt1, const pair<double, double>& pt2)
 {
     if ( pt1.second != pt2.second)
         return false;
-
     return pt1.second < pt2.second;
 }
 
@@ -509,15 +479,9 @@ bool compare(const pair<double, double>& pt1, const pair<double, double>& pt2)
 
 void GribDecoder::newPoint(const Transformation& transformation, double lat, double lon, double uc, double vc, double cc, vector<CustomisedPoint*>& points, double grid)
 {
-
-
-
     std::stack<UserPoint>   duplicates;
     UserPoint geo(lon, lat);
 
-
-
-
     transformation.wraparound(geo, duplicates);
     while (duplicates.empty() == false) {
         UserPoint pt = duplicates.top();
@@ -554,10 +518,8 @@ void GribDecoder::newPoint(const Transformation& transformation, double lat, dou
         points.push_back(point);
         if ( cc != -9999 ) {
             point->insert(make_pair("colour_component", cc));
-
         }
         duplicates.pop();
-
     }
 }
 
@@ -565,7 +527,6 @@ void GribDecoder::newPoint(const Transformation& transformation, double lat, dou
 
 struct Compare
 {
-
     template< typename T1, typename T2 >
     bool operator()( T1 const& t1, T2 const& t2 ) const
     {
@@ -594,9 +555,6 @@ void GribDecoder::customisedPoints(const Transformation& transformation, Customi
         vector<pair<double, double> >::iterator pos = positions.begin();
         out.reserve(positions.size());
 
-
-
-
         int i = 0;
         for ( pos = positions.begin(); pos != positions.end(); ++pos) {
             double offset = 0.;
@@ -604,8 +562,6 @@ void GribDecoder::customisedPoints(const Transformation& transformation, Customi
             double lon = pos->first;
             double lat = pos->second;
 
-
-
             i++;
             while ( lon < minlon ) {
                 lon += 360;
@@ -616,7 +572,6 @@ void GribDecoder::customisedPoints(const Transformation& transformation, Customi
                 offset += 360.;
             }
 
-
             Index index = interpretor_->nearest(lat, lon);
             //cout << "[" << lat << ", " << lon << "]-->[" << index.index_ << ", " << index.lat_ << ", " << index.lon_ << "]" << endl;
             if ( index.index_ != -1 && !index.used_ ) {
@@ -624,7 +579,6 @@ void GribDecoder::customisedPoints(const Transformation& transformation, Customi
                 double u = uComponent(index.index_);
                 double v = vComponent(index.index_);
 
-
                 if ( u != missing && v != missing) {
                     CustomisedPoint *add = new CustomisedPoint(index.lon_+offset, index.lat_, "");
                     pair<double, double> value = (*wind_mode_)(u, v);
@@ -644,7 +598,6 @@ void GribDecoder::customisedPoints(const Transformation& transformation, Customi
         }
     }
 
-
     else { // no thinning !
         // get all the points of the index!
 
@@ -663,16 +616,14 @@ void GribDecoder::customisedPoints(const Transformation& transformation, Customi
                         out.push_back(add);
                     }
                 }
-
             }
         }
     }
-
 }
 
+
 void GribDecoder::customisedPoints(const BasicThinningMethod& thinning, const Transformation& transformation, const std::set<string>& needs, CustomisedPointsList& points)
 {
-
     openFirstComponent();
     long repres;
     grib_get_long(handle_,"dataRepresentationType",&repres);
@@ -683,7 +634,6 @@ void GribDecoder::customisedPoints(const BasicThinningMethod& thinning, const Tr
         }
 
         // Compute the thinning factor...
-
         double gap = 0;
         // find the middle point :
         UserPoint ll = transformation.reference();
@@ -691,26 +641,23 @@ void GribDecoder::customisedPoints(const BasicThinningMethod& thinning, const Tr
         ll.y_ = ll.y_ + interpretor_->XResolution(*this);
         PaperPoint xy2 = transformation(ll);
 
-
-
         gap = xy1.distance(xy2);
         if ( thinning.factor() == 1 ) {
             gap = 0;
-
         }
         thinning_debug_ = ( needs.find("debug") != needs.end() );
         customisedPoints(transformation, points,
                 gap * thinning.factor(),
                 gap * thinning.factor(), gap);
-
     }
     catch (NoFactoryException&)
     {
-        MagLog::error() << "Grib Decoder: Representation [" << representation << "] not yet supported.\n"<< std::endl;;
-        throw MagicsException("Grib Decoder: Representation [] not yet supported.");
+        MagLog::error() << "Grib Decoder- customisedPoints: Representation [" << representation << "] not supported.\n"<< std::endl;;
+        throw MagicsException("Grib Decoder: Representation [] not supported.");
     }
 }
 
+
 void GribDecoder::decode2D(const Transformation&)
 {
     Data::dimension_ = 2;
@@ -718,8 +665,6 @@ void GribDecoder::decode2D(const Transformation&)
     Matrix     *w1 = 0;
     Matrix     *w2 = 0;
 
-
-
     const string representation = getString("typeOfGrid");
 
     try {
@@ -727,16 +672,14 @@ void GribDecoder::decode2D(const Transformation&)
             interpretor_ = SimpleObjectMaker<GribInterpretor>::create(representation);
         }
         readColourComponent();
-
         openFirstComponent();
         read(&w1);
         openSecondComponent();
         read(&w2);
-
     }
     catch (NoFactoryException&)
     {
-        MagLog::warning() << "Grib Decoder: Representation [" << representation << "] not yet supported.\n"<< std::endl;;
+        MagLog::warning() << "Grib Decoder: Vector representation [" << representation << "] not supported.\n"<< std::endl;;
     }
     wind_mode_->x(&xComponent_, &yComponent_, w1, w2);
 }
@@ -744,13 +687,10 @@ void GribDecoder::decode2D(const Transformation&)
 
 void GribDecoder::openFirstComponent()
 {
-
-
     grib_field_position_ =  position_1_;
-
     component1_ = open(component1_);
-
 }
+
 grib_handle* GribEntryDecoder::open(grib_handle* handle, bool) {
     if ( !handle_ ) {
         return handle_;
@@ -760,17 +700,16 @@ grib_handle* GribEntryDecoder::open(grib_handle* handle, bool) {
 
 void GribDecoder::openSecondComponent()
 {
-
     grib_field_position_ =  position_2_;
     component2_ = open(component2_);
-
 }
+
 void GribDecoder::openThirdComponent()
 {
     grib_field_position_ =  colour_position_;
     colour_ = open(colour_, false);
-
 }
+
 void GribDecoder::readColourComponent()
 {
     grib_field_position_ =  colour_position_;
@@ -778,14 +717,10 @@ void GribDecoder::readColourComponent()
         colour_ = open(colour_, false);
         read(&colourComponent_);
     }
-
     catch (...) {
         colourComponent_ = 0;
         valid_ = true;
     }
-
-
-
 }
 
 grib_handle*  GribDecoder::open(grib_handle* grib, bool sendmsg)
@@ -852,6 +787,8 @@ bool GribDecoder::id(const string& id, const string& where) const
     }
     return magCompare(id_, id);
 }
+
+
 bool GribDecoder::verify(const string& val) const
 {
     // we except a string with the following format "key1=val,key2=val2,...,keyn=valn"
@@ -902,17 +839,15 @@ void GribDecoder::decodePoints()
         }
         catch (NoFactoryException&)
         {
-            MagLog::warning() << "Grib Decoder: Representation [" << representation << "] not yet supported.\n"<< std::endl;;
+            MagLog::warning() << "Grib Decoder: Representation [" << representation << "] not supported.\n"<< std::endl;;
             scaling =1 ; offset =0;
         }
 
         grib_iterator* iter = grib_iterator_new(handle_, flags, &error);
 
-
-
         if (!iter)
         {
-            MagLog::error() << "Grib Iterator not yet supported on this kind of grib\n";
+            MagLog::error() << "Grib Iterator not yet supported on this kind of GRIB\n";
             MagLog::broadcast();
             throw MagicsException("Grib Iterator not yet supported.");
         }
@@ -937,7 +872,7 @@ void GribDecoder::decodePoints()
     grib_iterator* iter2 = grib_iterator_new(handle_, flags, &error);
     if (!iter1 || !iter2)
     {
-        MagLog::error() << "Grib Iterator not yet supported on this kind of grib\n";
+        MagLog::error() << "Grib Iterator not yet supported on this kind of GRIB\n";
         throw MagicsException("Grib Iterator not yet supported.");
     }
 
@@ -956,8 +891,6 @@ void GribDecoder::decodePoints()
 
 
 
-
-
 GribLoop::~GribLoop()
 {
     for (vector<GribDecoder*>::const_iterator g = gribs_.begin(); g != gribs_.end(); ++g)
@@ -998,13 +931,11 @@ void GribLoop::setToFirst()
 {
     currentDim_ = dimension_.begin();
     currentPos_ = dim_.begin();
-
 }
 
 
 bool  GribLoop::hasMore()
 {
-
     if (file_ == 0 ) {
         file_ = fopen(path_.c_str(),"r");
         if (!file_) {
@@ -1013,15 +944,11 @@ bool  GribLoop::hasMore()
         }
     }
 
-
-
     // Now we have to find the right Entry!!!
 
-
     if ( currentDim_ == dimension_.end() )
         return false;
 
-
     if ( *currentDim_ == 1 ) {
         if (  dim_.empty() ) {
             // case 1 dimension= 1 and loop on all the fields!
@@ -1191,9 +1118,7 @@ public:
             const long step =  computeStep(grib_, "stepRange");
             full = full + (step * -1);
         }
-
         return full.tostring(format);
-
     }
 
     string startDate(const XmlNode& node)
@@ -1254,11 +1179,8 @@ public:
         full = full + step;
 
         return full.tostring(format);
-
     }
 
-
-
     void visit(const XmlNode& node)
     {
         if ( magCompare(node.name(), "grib_info") )
@@ -1402,11 +1324,8 @@ void GribDecoder::nearestGridpoints(double *inlats, double *inlons, double *outl
         retainGribNearestHandle = true;  // more efficient
     }
 
-
     nearHandle = nearest_point_handle(retainGribNearestHandle);
 
-
-
     for (int i=0; i < nb; i++)
     {
         if (nearHandle)
@@ -1434,14 +1353,13 @@ void GribDecoder::nearestGridpoints(double *inlats, double *inlons, double *outl
 
     if (!retainGribNearestHandle && nearHandle) // was this a temporary handle?
         grib_nearest_delete(nearHandle);
-
 }
 
+
 void GribDecoder::visit(ValuesCollector& points)
 {
     field_ = open(field_);
 
-
     points.setCollected(true);
 
     int nb = points.size();
@@ -1469,7 +1387,7 @@ void GribDecoder::visit(ValuesCollector& points)
     }
     catch (NoFactoryException&)
     {
-        MagLog::warning() << "Grib Decoder: Representation [" << representation << "] not yet supported.\n"<< std::endl;;
+        MagLog::warning() << "Grib Decoder: Representation [" << representation << "] not supported.\n"<< std::endl;;
         scaling =1 ; offset =0;
     }
 
@@ -1539,6 +1457,7 @@ void GribDecoder::visit(MagnifierCollector& magnifier)
         points.advance();
     }
 }
+
 const DateDescription& GribDecoder::timeStamp()
 {
     vector<string> need;
@@ -1551,13 +1470,10 @@ const DateDescription& GribDecoder::timeStamp()
     for ( vector<string>::const_iterator t = need.begin(); t != need.end(); ++t )
         tag1.decode(*t);
 
-
     timeStamp_ = DateDescription(helper.get("grib", "valid-date"), index_, internalIndex_);
     dataLevel_ = LevelDescription::level(helper.get("grib", "typeOfLevel"), tonumber(helper.get("grib", "level")), index_, internalIndex_);
 
-
     return timeStamp_;
-
 }
 
 const LevelDescription& GribDecoder::level()
@@ -1576,7 +1492,6 @@ void GribDecoder::visit(MetaDataVisitor& meta)
     need.push_back("<grib_info key='base-date' format='%Y-%m-%d %H:%M:00'/>");
     need.push_back("<grib_info key='valid-date' format='%Y-%m-%d %H:%M:00'/>");
 
-
     TagHandler helper;
     GribTag tag1(*this, helper);
     for ( vector<string>::const_iterator t = need.begin(); t != need.end(); ++t )
@@ -1683,15 +1598,53 @@ void GribDecoder::visit(MetaDataCollector& step)
                     }
                     catch (NoFactoryException&)
                     {
-                        MagLog::warning() << "Grib Decoder: Representation [" << representation << "] not yet supported.\n"<< std::endl;;
+                        MagLog::warning() << "Grib Decoder: Representation [" << representation << "] not supported.\n"<< std::endl;;
                         information_[key->first]="N/A";
                     }
 
                 }
 
+                else if(key->first == "isOctahedral")
+                {
+                    // Octahedral reduced Gaussian grids:
+                    // - only reduced Gaussian grids can be octahedral
+                    // - the isOctahedral key only works properly with global fields
+                    string representation = getString("typeOfGrid");
+                    if (representation == "reduced_gg")
+                    {
+                        if (getLong("global") == 1)
+                        {
+                            information_["isOctahedral"] = (getLong("isOctahedral") == 1) ? "yes" : "no";
+                        }
+                    }
+                }
+/*
+                // alternative code, for if we want to display in one line the Gaussian
+                // number and the octahedral flag.
+                else if(key->first == "GaussianNumber")
+                {
+                    // e.g. N200 ('classic' reduced Gaussian) or O1280 ('octahedral' reduced Gaussian)
+                    // - but only use prefix of N or O on global fields, because, as explained below,
+                    //   we don't know whether a sub-areas field is classic or octahedral
+                    // Octahedral reduced Gaussian grids:
+                    // - only reduced Gaussian grids can be octahedral
+                    // - the isOctahedral key only works properly with global fields
+                    string representation = getString("typeOfGrid");
+                    if (representation == "reduced_gg")
+                    {
+                        long N = getLong("N");
+                        string prefix("");
+                        if (getLong("global") == 1)
+                        {
+                            prefix = (getLong("isOctahedral") == 1) ? "O" : "N";
+                        }
+                        information_["GaussianNumber"] = prefix + tostring(N);
+                    }
+                }*/
             }
+            
             //If key is found in information_ we copy it
-            else
+            if(information_.find(key->first) != information_.end())
             {
                 key->second=information_[key->first];
             }
@@ -1873,8 +1826,8 @@ void GribDecoder::decodeRaster(const Transformation& transformation)
 
     catch (NoFactoryException&)
     {
-        MagLog::error() << "Grib Decoder: Representation [" << representation << "] not yet supported.\n";
-        throw MagicsException("Grib Decoder: Representation [] not yet supported.");
+        MagLog::error() << "Grib Decoder: Raster representation [" << representation << "] not supported.\n";
+        throw MagicsException("Grib Decoder: Raster representation [] not supported.");
     }
 }
 
@@ -2345,7 +2298,6 @@ public:
             title.back() += sat->second;
         else
             title.back() += "satellite identifier " + tostring(ident);
-
     }
 };
 
@@ -2416,7 +2368,6 @@ public:
     ~GribExpverHandler() {}
     void operator()(TitleField& field, vector<string>& title, const GribDecoder& grib)
     {
-
         if ( !grib.getExpver() ) return;
         ostringstream out;
         string expver = grib.getString("mars.experimentVersionNumber");
@@ -2449,7 +2400,6 @@ public:
         //        title.add(out.str());
 
         title.back() +=  "epsnumber?";
-
     }
 };
 
@@ -2484,6 +2434,7 @@ public:
          */
     }
 };
+
 double GribDecoder::uComponent(int index)
 {
     return xValues_[index];
@@ -2493,6 +2444,7 @@ double GribDecoder::vComponent(int index)
 {
     return yValues_[index];
 }
+
 void GribDecoder::uComponent()
 {
     if ( xValues_ )
@@ -2505,6 +2457,7 @@ void GribDecoder::uComponent()
     xValues_ = new double[nb];
     grib_get_double_array(handle, "values", xValues_, &nb);
 }
+
 void GribDecoder::vComponent()
 {
     if ( yValues_ )
