@@ -167,14 +167,12 @@ void GribInterpretor::new_index(const GribDecoder& grib)
             continue;
     	}
 
-
         if ( minlat_ > lat) minlat_ = lat;
         if ( maxlat_ < lat) maxlat_ = lat;
         if ( minlon_ > lon) minlon_ = lon;
         if ( maxlon_ < lon) maxlon_ = lon;
 
-    	if ( lon < 0 ) lon +=360.;
-        ilat = floor((lat+90)/indexStep_);
+    	ilat = floor((lat+90)/indexStep_);
         ilon = floor(lon/indexStep_);
 
 
@@ -205,14 +203,10 @@ Index GribInterpretor::nearest(double ulat, double ulon)
         return index;
     if ( ulat > maxlat_ ) 
         return index;
-    bool out = true;
-    if ( ulon >= minlon_ && ulon <= maxlon_)
-    	out = false;
-    if ( ulon-360 >= minlon_ && ulon-360 <= maxlon_)
-       	out = false;
-
-    if ( out )
-    	return index;
+    if ( ulon < minlon_ ) 
+        return index;
+    if ( ulon > maxlon_ ) 
+        return index;
 
     
     if ( ulat == -1000. || ulon == -1000.)
@@ -223,7 +217,6 @@ Index GribInterpretor::nearest(double ulat, double ulon)
 
 
 
-
     int ilat = floor((ulat+90)/indexStep_);
     int ilon = floor(ulon/indexStep_);
     int lat1, lat2;
@@ -975,12 +968,66 @@ void GribReducedGaussianInterpretor::interpretAsMatrix(const GribDecoder& grib,
     long global = grib.getLong("global");
 
     // We have to determine if the field is global!
-        if (global) {
-            east = west + 360.;
-        }
+    if (global) {
+        east = west + 360.;
+    }
     vector<vector<double> > rows;
 
+
     for ( int i = 0; i < nblat; i++) {
+        long numPts = 0;
+        long indexFirst, indexLast;
+        int globalPointsInThisRow = pl[i];
+        double dx = 360./pl[i];
+
+
+        // find which points are in this row; a sub-area of a reduced Gaussian grid
+        // contains a subset of the points from the global grid, with the points
+        // in exactly the same positions as the corresponding ones in the
+        // global grid. The GRIB_API function grib_get_reduced_row() does not
+        // produce the correct result when given a global field, so we need
+        // to make that a separate case.
+
+        double add = 0;
+
+        if (global) {
+            numPts     = globalPointsInThisRow;
+            indexFirst = 0;
+            indexLast  = numPts-1;
+
+        }
+        else {
+            grib_get_reduced_row(globalPointsInThisRow, west, east,
+                                 &numPts, &indexFirst,&indexLast);
+            add = 2*dx;
+        }
+
+        rows.push_back(vector<double>());
+
+        int n = indexFirst;
+
+
+        // the index of the first point is not necessarily smaller than the index
+        // of the second point, depending on the sub-area.
+        // we need to check whether the last index is the last point; however,
+        // grib_get_reduced_row() seems to sometimes return a numPoints which is 1
+        // greater than the number of global points in the row so we need a double
+        // check.
+        bool lastSubAreaIndexIsNotLastGlobalIndex = (indexLast != globalPointsInThisRow-1) &&
+                                                    (indexLast != globalPointsInThisRow);
+
+        while (n != indexLast+1){
+            double thisLon = n*dx;
+            if ( thisLon > east +add) thisLon -= 360.;
+
+            rows.back().push_back(thisLon);
+            n++;
+            if (n == globalPointsInThisRow && lastSubAreaIndexIsNotLastGlobalIndex )  // wrap around?
+                n = 0;
+        }
+
+/*
+        // this is the previous version of the code (before using grib_get_reduced_row())
         // compute find first grid point ..
         double dx = 360./pl[i];
         rows.push_back(vector<double>());
@@ -994,6 +1041,7 @@ void GribReducedGaussianInterpretor::interpretAsMatrix(const GribDecoder& grib,
 
             }
         }
+*/		// This line is suspicious! but I keep it ... Jsut in case!
         std::sort(rows.back().begin(), rows.back().end());
 
 
