@@ -52,7 +52,7 @@ extern "C"{
 #include <gd.h>
 #endif
 
-#ifdef MAGICS_CAIRO
+#ifdef HAVE_CAIRO
 #include <cairo.h>
 #include <CairoDriver.h>
 #endif
@@ -124,7 +124,9 @@ void KMLDriver::open()
 		<< "     xmlns:atom=\"http://www.w3.org/2005/Atom\">\n"
 		<< "<Document>\n"<< " <name>"<<title_<<"</name>\n"
 		<< " <open>1</open>\n";
-	pFile_  << " <atom:generator>"<<getMagicsVersionString()<<"</atom:generator>\n";
+	pFile_  << " <atom:generator>";
+	if(!output_creator_.empty()) pFile_ <<output_creator_<<" using ";
+	pFile_  <<getMagicsVersionString()<<"</atom:generator>\n";
 	if(!author_.empty()) pFile_ << " <atom:author><atom:name>"<<author_<<"</atom:name></atom:author>\n";
 	if(!link_.empty())   pFile_ << " <atom:link href=\""<<link_<<"\" />\n";
 	pFile_	<< " <description>\n"
@@ -167,13 +169,13 @@ void KMLDriver::close()
 
     if(ecmwf_logo_)
     {
-       const string logofilename = "kml_logo.png";
+       const string logofilename = "kml_logo_2014.png";
        const string logofile = path + logofilename;
        is_copied = copy_file(logofile,logofilename);
        if(is_copied) kml_output_resource_list_.push_back(logofilename);
    
        pFile_ << "<ScreenOverlay id=\"logo\">\n"
-              << "<name>MagLogo</name>\n"
+              << "<name>MagicsLogo</name>\n"
               << "<Icon>\n"
               << " <href>"<<logofilename<<"</href>\n"
               << "</Icon>\n"
@@ -338,7 +340,7 @@ MAGICS_NO_EXPORT void KMLDriver::project(const magics::Layout& layout) const
 
 MAGICS_NO_EXPORT void KMLDriver::redisplay(const magics::LegendLayout& layout) const
 {
-#ifdef MAGICS_CAIRO
+#ifdef HAVE_CAIRO
     //redisplay((const Layout&) legend);
     const string filename = "legend.png";
     cairo_surface_t* surface_ = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, layout.width(), layout.height());
@@ -796,7 +798,7 @@ MAGICS_NO_EXPORT bool KMLDriver::renderPixmap(MFloat x0,MFloat y0,MFloat x1,MFlo
   if(render_)
   {
 	if (kml_placemark_) closePlacemark();
-#ifndef MAGICS_CAIRO
+#ifndef HAVE_CAIRO
 #ifndef MAGICS_RASTER
 	MagLog::warning() << "Image import is not implemented for the used driver!!!" << endl; return false;
 #else
@@ -962,7 +964,7 @@ MAGICS_NO_EXPORT bool KMLDriver::renderCellArray(const Image& image) const
    if(render_)
    {
 	if (kml_placemark_) closePlacemark();
-#ifndef MAGICS_CAIRO
+#ifndef HAVE_CAIRO
 #ifndef MAGICS_RASTER
 	MagLog::warning() << "Image import is not implemented for the used driver!!!" << endl; return false;
 #else
