@@ -166,17 +166,18 @@ MAGICS_NO_EXPORT void SVGDriver::startPage() const
 
 	if(!desc_.empty()) pFile_<< "<desc>"<<desc_<<"</desc>\n";
 	const SystemInfo info;
-	pFile_<< "<metadata id=\"MAGICSmetadata\">\n<rdf:RDF><cc:Work rdf:about=\"\">\n"
-	      << "\t<dc:format>image/svg+xml</dc:format>\n"
-	      << "\t<dc:title>"<<title_<<"</dc:title>\n"
-	      << "\t<dc:creator><cc:Agent><dc:title>"<<info.getUserID()<<" on "<<info.getHostName()<<"</dc:title></cc:Agent></dc:creator>\n"
-	      << "\t<dc:date>"<<info.getTime()<<"</dc:date>\n"
-	      << "\t<dc:language>en-GB</dc:language>\n"
-	      << "\t<dc:description>Meteorological plot generated by "<<getMagicsVersionString()<<"</dc:description>\n"
-	      << "\t<dc:publisher><cc:Agent>\n"
-	      << "\t <dc:title>"<<getMagicsVersionString()<<"</dc:title>\n"
-	      << "\t</cc:Agent></dc:publisher>\n"
-	      << "\t<dc:coverage>Plot of meteorological data</dc:coverage>\n";
+	pFile_ << "<metadata id=\"MAGICSmetadata\">\n<rdf:RDF><cc:Work rdf:about=\"\">\n"
+	       << "\t<dc:format>image/svg+xml</dc:format>\n"
+	       << "\t<dc:title>"<<title_<<"</dc:title>\n"
+	       << "\t<dc:author>"<<info.getUserID()<<" on "<<info.getHostName()<<"</dc:author>\n"
+	       << "\t<dc:date>"<<info.getTime()<<"</dc:date>\n"
+	       << "\t<dc:language>en-GB</dc:language>\n";
+	if(!desc_.empty()) pFile_ << "\t<dc:description>"<<desc_<<"</dc:description>\n";
+	if(!output_creator_.empty()) pFile_ << "\t<dc:creator><cc:Agent><dc:title>"<<output_creator_<<"</dc:title></cc:Agent></dc:creator>\n";
+	pFile_ << "\t<dc:publisher><cc:Agent>\n"
+	       << "\t <dc:title>"<<getMagicsVersionString()<<"</dc:title>\n"
+	       << "\t</cc:Agent></dc:publisher>\n"
+	       << "\t<dc:coverage>Plot of meteorological data</dc:coverage>\n";
 	if(!meta_.empty()) pFile_<< "<!-- \n"<<meta_<<"\n-->\n";
 	pFile_<<"</cc:Work></rdf:RDF>\n</metadata>\n";
 /*
@@ -1052,8 +1053,8 @@ MAGICS_NO_EXPORT void SVGDriver::renderText(const Text& text) const
 		}
 		else
 		{
-		  pFile_ <<"<tspan "
-		      <<"font-size=\""<<dheight<<"cm\" font-family=\""<< ttf << "\" ";
+		  pFile_ <<"<tspan dominant-baseline=\""<<verticalJustification<< "\""
+		      <<" font-size=\""<<dheight<<"cm\" font-family=\""<< ttf << "\" ";
 		  if(styles.find("bolditalic") != styles.end()) pFile_ <<"font-weight=\"bold\" font-style=\"italic\" ";
 		  else if(styles.find("bold")  != styles.end()) pFile_ <<"font-weight=\"bold\" ";
 		  else if(styles.find("italic")!= styles.end()) pFile_ <<"font-style=\"italic\" ";
@@ -1103,10 +1104,12 @@ MAGICS_NO_EXPORT void SVGDriver::circle(const MFloat x, const MFloat y, const MF
 		else
 		{
 		 const short  i   = (s<4) ? 1 : 0;
-		 const double rad = s*0.7853981634*r;
-		 pFile_	<< "<path d=\"M"<<cx<<" "<<cy-r<<" A"<<r<<","<<r<<" 0 "<<i<<" 1 "
-			<< cx+cos(rad)<<" "<<cy+sin(rad)<<"\" "
-			<< "fill=\"rgb("
+		 const double rad = s*0.7853981634;
+
+		 if(s==2)      pFile_ << "<path d=\"M"<<cx<<" "<<cy-r<<" v"<<r<<" h"<<r<<" a"<<r<<","<<r<<" 0 0 0 "<< -r<<","<<-r<<"\" ";
+		 else if(s==4) pFile_ << "<path d=\"M"<<cx<<" "<<cy-r<<" v"<<2*r<<" a"<<r<<","<<r<<" 0 0 0 "<< 0<<","<<-2*r<<"\" ";
+		 else if(s==6) pFile_ << "<path d=\"M"<<cx<<" "<<cy-r<<" v"<<r<<" h"<<-r<<" a"<<r<<","<<r<<" 1 1 0 "<< r<<","<<-r<<"\" ";
+		 pFile_	<< "fill=\"rgb("
 			<< static_cast<int>(currentColour_.red()  *255) << ","
 			<< static_cast<int>(currentColour_.green()*255) << ","
 			<< static_cast<int>(currentColour_.blue() *255) << ")\""
@@ -1140,7 +1143,7 @@ MAGICS_NO_EXPORT void SVGDriver::circle(const MFloat x, const MFloat y, const MF
 			<< static_cast<int>(currentColour_.blue() *255) << ")\"";
 		openGroup(stream.str());
 		pFile_	<< "<circle cx=\""<<cx<<"\" cy=\""<<cy<<"\" r=\""<<r<<"\"/>\n"
-			<< "<polyline points=\"0,"<<r*.9<<" 0,"<<-r*.9<<"\" width=\"2\" stroke=\"white\" fill=\"white\"/>"<< std::endl;
+			<< "<polyline points=\""<<cx<<","<<cy+(r*.9)<<" "<<cx<<","<<cy-(r*.9)<<"\" width=\"2\" stroke=\"white\" fill=\"white\"/>"<< std::endl;
 	}
 
 }
@@ -1476,24 +1479,40 @@ MAGICS_NO_EXPORT void SVGDriver::renderSymbols(const Symbol& symbol) const
 	debugOutput("Symbols - START");
 	closeGroup();
 
-	const string location = logoLocation_;
-
-	if(symbol.getSymbol()=="logo_ecmwf" && !magCompare(location,"INLINE") )
+	if(symbol.getSymbol()=="logo_ecmwf")
 	{
-          if(inkscape_) pFile_ << "<g inkscape:groupmode=\"layer\" inkscape:label=\"ECMWF_logo\">\n"
+      if(inkscape_) pFile_ << "<g inkscape:groupmode=\"layer\" inkscape:label=\"ECMWF_logo\">\n"
                                << " <title>ECMWF_logo</title>\n";
-
 	  const MFloat x = projectX(symbol[0].x());
 	  const MFloat y = projectY(symbol[0].y());
 
-	  string logofile;
-	  if(magCompare(location,"LOCAL")) logofile = "ecmwf_logo.png";
-	  else logofile = getEnvVariable("MAGPLUS_HOME") + MAGPLUS_PATH_TO_SHARE_ + "ecmwf_logo.png";
-	  svg_output_resource_list_.push_back(logofile);
-	  pFile_ << "<a xlink:href=\"http://www.ecmwf.int\">"
+	  if(!magCompare(logoLocation_,"INLINE") )
+	  {
+	    string logofile;
+	    if(magCompare(logoLocation_,"LOCAL")) logofile = "ecmwf_logo.png";
+	    else logofile = getEnvVariable("MAGPLUS_HOME") + MAGPLUS_PATH_TO_SHARE_ + "ecmwf_logo.png";
+	    svg_output_resource_list_.push_back(logofile);
+	    pFile_ << "<a xlink:href=\"http://www.ecmwf.int\">"
 	         << "<image x=\""<<x-(y*1.35)<<"\" y=\""<<setY(y+(y*.5))<<"\" width=\""<<y*5.4<<"\" height=\""<<y<<"\" xlink:href=\""<<logofile<<"\" />"
 	         << "</a>\n";
-	  if(inkscape_) pFile_ << "</g>\n";
+	  }
+	  else
+	  {
+	  	pFile_ << "<g transform=\"translate("<<x-(y*1.35)<<","<<setY(y+(y*.5))<<")\">\n";
+	  	const string s = getEnvVariable("MAGPLUS_HOME") + MAGPLUS_PATH_TO_SHARE_ + "ecmwf_logo_2014.svg";
+	    ifstream psfile(s.c_str());
+
+	    if(!psfile){
+		  MagLog::error() << "PostScriptDriver::copyMacro() --> Cannot open PostScript Macro file! " << s <<
+		   " Is MAGPLUS_HOME set correctly?\n";
+		  return;
+	    }
+	    char ch;
+	    while (psfile.get(ch)){pFile_.put(ch);}
+	    psfile.close();
+	    pFile_ << "</g>\n";
+	  }
+	  if(inkscape_) pFile_ << "</g><!-- Logo end -->\n";
 	}
 	else 
 		BaseDriver::renderSymbols(symbol);
